<?php
/*
 * Plugin Name: Asset CleanUp: Page Speed Optimization
 * Plugin URI: https://wordpress.org/plugins/wp-asset-clean-up/
 * Version: 1.2.7
 * Description: Prevent Chosen Scripts & Styles from loading in Posts/Pages to reduce HTTP Requests and have the website load faster
 * Author: Gabriel Livan
 * Author URI: http://www.gabelivan.com/
*/

define('WPACU_PLUGIN_VERSION', '1.2.7');

// Exit if accessed directly
if (! defined('ABSPATH')) {
    exit;
}

// Premium plugin version already exists, is it active?
// Do not load the LITE version as it's pointless
// This action is valid starting from LITE version 1.2.6.8
// From 1.0.3, the PRO version works independently (does not need anymore LITE to be active and act as a parent plugin)

// If the pro version (version above 1.0.2) was triggered first, we'll just check one of its constants
// If the lite version was triggered first, then we'll check if the pro version is active
if (defined('WPACU_PRO_NO_LITE_NEEDED') && WPACU_PRO_PLUGIN_VERSION === true) {
	return;
}

include_once(ABSPATH . 'wp-admin/includes/plugin.php');

if (file_exists(dirname(dirname(__FILE__)).'/wp-asset-clean-up-pro/wpacu.php') && is_plugin_active('wp-asset-clean-up-pro/wpacu.php')) {
	return;
}

define('WPACU_PLUGIN_NAME', 'wpassetcleanup');
define('WPACU_PLUGIN_CLASSES_PATH', dirname(__FILE__).'/classes/');
define('WPACU_PLUGIN_FILE', __FILE__);
define('WPACU_PLUGIN_BASE', plugin_basename(WPACU_PLUGIN_FILE));
define('WPACU_PLUGIN_URL', plugins_url('', WPACU_PLUGIN_FILE));

// Upgrade to Pro Sales Page
define('WPACU_PLUGIN_GO_PRO_URL', 'https://www.gabelivan.com/items/wp-asset-cleanup-pro/');

// Do not load the plugin if the PHP version is below 5.3
$wpacuWrongPhp = version_compare(PHP_VERSION, '5.3.0', '<');

if (is_admin() && $wpacuWrongPhp) { // Dashboard
    add_action('admin_init', 'wpAssetCleanUpWrongPhp');
    add_action('admin_notices', 'wpAssetCleanUpWrongPhpNotice');

    /**
     * Deactivate the plugin because it has the wrong PHP version installed
     */
    function wpAssetCleanUpWrongPhp()
    {
        deactivate_plugins(WPACU_PLUGIN_BASE);

        // The premium extension too (if any)
        deactivate_plugins('wp-asset-clean-up-pro/wpacu-pro.php');
	    deactivate_plugins('wp-asset-clean-up-pro/wpacu.php');
    }

    /**
     * Print the message to the user after the plugin was deactivated
     */
    function wpAssetCleanUpWrongPhpNotice()
    {
        echo '<div class="error is-dismissible"><p>'.
             __('<strong>Asset CleanUp</strong> requires <span style="color: green;"><strong>5.3+</strong> PHP version</span> installed. You have <strong>'.PHP_VERSION.'</strong>. If you\'re website is compatible with PHP 7+ (e.g. you can check with your developers or contact the hosting company), it\'s strongly recommended to upgrade for a better performance. The plugin has been deactivated.', WPACU_PLUGIN_NAME).
             '</p></div>';

        if (array_key_exists('active', $_GET)) {
            unset($_GET['activate']);
        }
    }
} elseif ($wpacuWrongPhp) { // Front
    return;
}

require_once dirname(WPACU_PLUGIN_FILE).'/wpacu-load.php';
